Module timer

Module timer 

Structs

Timer
Timer is an iterator that sleeps an appropriate amount of time between iterations so that we can sample the process a certain number of times a second. We’re using an irregular sampling strategy to avoid aliasing effects that can happen if the target process runs code at a similar schedule as the profiler: https://github.com/benfred/py-spy/issues/94